@@ -22,85 +22,62 @@
  *
  */
 
-#ifndef LMMS_GUI_GUI_APPLICATION_H
-#define LMMS_GUI_GUI_APPLICATION_H
+#ifndef GUIAPPLICATION_H
+#define GUIAPPLICATION_H
 
-#include <QObject>
+#include <QtCore/QObject>
 
-#include "lmms_export.h"
-#include "lmmsconfig.h"
+#include "export.h"
 
 class QLabel;
-class QSocketNotifier;
-
-namespace lmms::gui
-{
 
 class AutomationEditorWindow;
+class BBEditor;
 class ControllerRackView;
-class MixerView;
+class FxMixerView;
 class MainWindow;
-class MicrotunerConfig;
-class PatternEditorWindow;
 class PianoRollWindow;
 class ProjectNotes;
 class SongEditorWindow;
 
-class LMMS_EXPORT GuiApplication : public QObject
+class EXPORT GuiApplication : public QObject
 {
 	Q_OBJECT;
 public:
 	explicit GuiApplication();
-	~GuiApplication() override;
+	~GuiApplication();
 
 	static GuiApplication* instance();
-	static void sigintHandler(int);
-	static bool isWayland();
-#ifdef LMMS_BUILD_WIN32
-	static QFont getWin32SystemFont();
-#endif
-
-	void createSocketNotifier();
 
 	MainWindow* mainWindow() { return m_mainWindow; }
-	MixerView* mixerView() { return m_mixerView; }
+	FxMixerView* fxMixerView() { return m_fxMixerView; }
 	SongEditorWindow* songEditor() { return m_songEditor; }
-	PatternEditorWindow* patternEditor() { return m_patternEditor; }
+	BBEditor* getBBEditor() { return m_bbEditor; }
 	PianoRollWindow* pianoRoll() { return m_pianoRoll; }
 	ProjectNotes* getProjectNotes() { return m_projectNotes; }
-	MicrotunerConfig* getMicrotunerConfig() { return m_microtunerConfig; }
 	AutomationEditorWindow* automationEditor() { return m_automationEditor; }
 	ControllerRackView* getControllerRackView() { return m_controllerRackView; }
 
-	//! File descriptors for unix socketpair, used to receive SIGINT
-	static inline int s_sigintFd[2];
-
 public slots:
 	void displayInitProgress(const QString &msg);
 
 private slots:
 	void childDestroyed(QObject *obj);
-	void sigintOccurred();
 
 private:
 	static GuiApplication* s_instance;
 
 	MainWindow* m_mainWindow;
-	MixerView* m_mixerView;
+	FxMixerView* m_fxMixerView;
 	SongEditorWindow* m_songEditor;
 	AutomationEditorWindow* m_automationEditor;
-	PatternEditorWindow* m_patternEditor;
+	BBEditor* m_bbEditor;
 	PianoRollWindow* m_pianoRoll;
 	ProjectNotes* m_projectNotes;
-	MicrotunerConfig* m_microtunerConfig;
 	ControllerRackView* m_controllerRackView;
 	QLabel* m_loadingProgressLabel;
-	QSocketNotifier* m_sigintNotifier;
 };
 
-// Short-hand function
-LMMS_EXPORT GuiApplication* getGUI();
+#define gui GuiApplication::instance()
 
-} // namespace lmms::gui
-
-#endif // LMMS_GUI_GUI_APPLICATION_H
+#endif // GUIAPPLICATION_H
